# GUI

The results GUI is a web interface for viewing measurement results.

The GUI is built using [plotly dash](https://plotly.com/dash/) which is a pure-python toolkit for making dynamic data 
dashboards.

The GUI provides a viewer for data and plots generated from the entropylab pipeline and a CRUD interface for the parameter store. 
